@@ -56,9 +56,10 @@ def get_synchronization_tasks(object_name):
              {'name': 'check_current_binhost',
               'message': __("Checking current binhost"),
               'essential': False,
-              'method': Object('check_current_binhost(update.cl_update_new_binhost)'),
+              'method': Object('check_current_binhost(update.cl_update_binhost)'),
               'condition': lambda GetBool, Get: (
                     not GetBool('update.cl_update_binhost_recheck_set') and
+                    not (Get('update.cl_update_binhost_choice') and Get('update.cl_update_binhost_choice') != 'auto') and
                     Get('update.cl_update_sync_rep') and
                     Get('update.cl_update_binhost') and 
                     Get('update.cl_update_use_migration_host') == 'off')
@@ -68,6 +69,14 @@ def get_synchronization_tasks(object_name):
               'method': Object("delete_binhost()"),
               'depend': AllTasks.failed_all("check_current_binhost")
              },
+             {'name': 'check_chosen_binhost',
+              'message': __("Checking chosen binhost"),
+              'method': Object('check_chosen_binhost(update.cl_update_binhost_choice)'),
+              'condition': lambda GetBool, Get: (
+                  not GetBool('update.cl_update_binhost_recheck_set') and
+                  Get('update.cl_update_binhost_choice') and
+                  Get('update.cl_update_binhost_choice') != 'auto'),
+              'depend': AllTasks.hasnot("check_current_binhost")},
              {'name': 'group_find_binhost',
               'group': '',
               'while': (~AllTasks.has_any("detect_best_binhost") &
@@ -84,9 +93,8 @@ def get_synchronization_tasks(object_name):
                   'depend': (Tasks.success() & ~AllTasks.has_any("not_use_search") &
                              (~AllTasks.success_one_of("check_current_binhost") |
                              AllTasks.success_all("sync_reps"))),
-                  'condition': lambda Get: Get('update.cl_update_use_migration_host') == 'off'# or
-                                        #(not Get("update.cl_update_binhost_recheck_set") and (not Get("update.cl_update_binhost_choice") != 'auto'
-                                         #or not Get("update.cl_update_binhost_choice")))
+                  'condition': lambda Get: Get('update.cl_update_use_migration_host') == 'off',
+                  'depend': AllTasks.hasnot("check_chosen_binhost"),
                  },
                  {'name': 'interrupt_on_no_leveled_binhost',
                   'method': Object("interrupt_on_no_leveled_binhost()"),
@@ -132,7 +140,8 @@ def get_synchronization_tasks(object_name):
                   'method': Object('update_local_info_binhost()'),
                   'condition': lambda Get: Get("update.cl_update_binhost_choice") == 'auto'
                                            or not Get("update.cl_update_binhost_choice")
-                                           or Get("update.cl_update_binhost_recheck_set")
+                                           or Get("update.cl_update_binhost_recheck_set"),
+                  'depend': AllTasks.hasnot('check_chosen_binhost')
                  },
                  {'name': 'sync_reps:update_binhost_list',
                   'essential': False,
