@@ -1745,15 +1745,6 @@ class VariableClUpdateBinhostChoice(Variable):
         return ['auto'] + self.Get("cl_update_binhost_list")
 
 
-class VariableClUpdateNewBinhost(Variable):
-    def get(self):
-        if self.Get('cl_update_binhost_choice'):
-            binhost = self.Get('cl_update_binhost_choice')
-            if binhost != 'auto':
-                return binhost
-        return self.Get('cl_update_binhost')
-
-
 class VariableClUpdateBinhost(Variable):
     """
     Хост с бинарными обновлениями
@@ -1844,14 +1835,8 @@ class VariableClUpdatePortageBinhost(ReadonlyVariable):
     """
     Прописываемый в /etc/portage/make.conf/binhost репозиторий
     """
-    #value_format = "{update.cl_update_binhost}/grp/{os_arch_machine}"
+    value_format = "{update.cl_update_binhost}/grp/{os_arch_machine}"
 
-    def get(self):
-        if not self.Get('update.cl_update_binhost_recheck_set') \
-                and self.Get('update.cl_update_binhost_choice') \
-                and self.Get('update.cl_update_binhost_choice') != 'auto':
-            return f"{self.Get('update.cl_update_binhost_choice')}/grp/{self.Get('os_arch_machine')}"
-        return f"{self.Get('update.cl_update_binhost')}/grp/{self.Get('os_arch_machine')}"
 
 class VariableClUpdatePackageCache(ReadonlyVariable):
     """
